..
    SPDX-FileCopyrightText: 2024 Alec Delaney, for Adafruit Industries
    SPDX-License-Identifier: MIT

Updating 10 Boards Rapidly
==========================

.. tabs::

    .. tab:: bash

        .. literalinclude:: ../../examples/bash/update_many.sh
            :language: bash

    .. tab:: powershell

        .. literalinclude:: ../../examples/powershell/update_many.ps1
            :language: powershell
